This is a very simple calculator. It can do addition, substraction, multiplication and division.
To run this package type the following in python shell:
Addition:
import xandar as xan
xan.add_num(a,b)

Substraction:
import xandar as xan
xan.sub_num(a,b):

Multiplication:
import xandar as xan
xan.mul_num(a,b)

Division:
import xandar as xan
xan.div_num(a,b)

